@@ -17,38 +17,37 @@
 #ifndef DIFF2_PARSER_H
 #define DIFF2_PARSER_H
 
-#include "diffmodellist.h"
 #include "kompare.h"
 
 namespace Diff2
 {
 
-class DiffModel;
+class DiffModelList;
 class KompareModelList;
 
 class Parser
 {
 public:
-	explicit Parser(const KompareModelList* list);
-	~Parser();
+    explicit Parser(const KompareModelList* list);
+    ~Parser();
 
 public:
-	DiffModelList* parse( QStringList& diffLines, bool* malformed = 0 );
+    DiffModelList* parse(QStringList& diffLines, bool* malformed = nullptr);
 
-	enum Kompare::Generator generator() const { return m_generator; };
-	enum Kompare::Format    format() const    { return m_format; };
+    enum Kompare::Generator generator() const { return m_generator; };
+    enum Kompare::Format    format() const    { return m_format; };
 
 private:
-	/** Which program was used to generate the output */
-	enum Kompare::Generator determineGenerator( const QStringList& diffLines );
+    /** Which program was used to generate the output */
+    enum Kompare::Generator determineGenerator(const QStringList& diffLines);
 
-	int cleanUpCrap( QStringList& diffLines );
+    int cleanUpCrap(QStringList& diffLines);
 
 private:
-	enum Kompare::Generator m_generator;
-	enum Kompare::Format    m_format;
+    enum Kompare::Generator m_generator;
+    enum Kompare::Format    m_format;
 
-	const KompareModelList* m_list;
+    const KompareModelList* m_list;
 };
 
 } // End of namespace Diff2
